==> haskell-conversion-text-1.0.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conversion-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conversion-text
version: 1.0.1
id: conversion-text-1.0.1-FGsEnkUjOnp70ed1szoxxp
key: conversion-text-1.0.1-FGsEnkUjOnp70ed1szoxxp
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/conversion-text
synopsis: "Conversion" instances for the "text" library
category: Control, Data, Conversion
abi: f257648649f4e3f2007ceb737fdd15d8
exposed: True
exposed-modules:
    Conversion.Text
import-dirs: /usr/lib/ghc-8.4.3/site-local/conversion-text-1.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/conversion-text-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/conversion-text-1.0.1
hs-libraries: HSconversion-text-1.0.1-FGsEnkUjOnp70ed1szoxxp
depends:
    text-1.2.3.0 bytestring-0.10.8.2
    conversion-1.2.1-GVMjU1MOI8glyOGflZe9J
    conversion-bytestring-1.0.1-C4EQTeKNsCmAFHtg6gAS6Z
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
abi-depends: text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             conversion-1.2.1-GVMjU1MOI8glyOGflZe9J=888a52c8d00cd845bc8154c6298a150f
             conversion-bytestring-1.0.1-C4EQTeKNsCmAFHtg6gAS6Z=262ad9da8f29656c1e1ed35a169436d2
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
haddock-interfaces: /usr/share/doc/haskell-conversion-text/html/conversion-text.haddock
haddock-html: /usr/share/doc/haskell-conversion-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conversion-text-1.0.1-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-conversion-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conversion-text
version: 1.0.1
id: conversion-text-1.0.1-HW73bImfShJCmmDZ53Ub6W
key: conversion-text-1.0.1-HW73bImfShJCmmDZ53Ub6W
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/conversion-text
synopsis: "Conversion" instances for the "text" library
category: Control, Data, Conversion
abi: 1162940c05b6aa4c53281b4ccfb8f936
exposed: True
exposed-modules:
    Conversion.Text
import-dirs: /usr/lib/ghc-8.6.1/site-local/conversion-text-1.0.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/conversion-text-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/conversion-text-1.0.1
hs-libraries: HSconversion-text-1.0.1-HW73bImfShJCmmDZ53Ub6W
depends:
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s bytestring-0.10.8.2
    conversion-1.2.1-8xBru6GHTVg3lh5nBJWaVP
    conversion-bytestring-1.0.1-Ic7N6B6esWlCE6vztSKndy text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-conversion-text/html/conversion-text.haddock
haddock-html: /usr/share/doc/haskell-conversion-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
